@@ -2,6 +2,9 @@ package Net::XMPP2::IM::Presence;
 use strict;
 use Net::XMPP2::Util;
 use Net::XMPP2::IM::Message;
+use Net::XMPP2::IM::Delayed;
+
+our @ISA = qw/Net::XMPP2::IM::Delayed/;
 
 =head1 NAME
 
@@ -15,6 +18,9 @@ This module represents an XMPP presence. It stores
 the full JID of the contact, the show value, status value
 and priority.
 
+L<Net::XMPP2::IM::Presence> is derived from L<Net::XMPP2::IM::Delayed>,
+use the interface described there to find out whether this presence was delayed.
+
 =head1 METHODS
 
 =over 4
@@ -37,6 +43,8 @@ sub clone {
 sub update {
    my ($self, $node) = @_;
 
+   $self->fetch_delay_from_node ($node);
+
    my $type       = $node->attr ('type');
    my ($show)     = $node->find_all ([qw/client show/]);
    my ($priority) = $node->find_all ([qw/client priority/]);
@@ -117,18 +125,23 @@ sub status {
    undef
 }
 
-=item B<make_message>
+=item B<make_message (%args)>
 
 Returns a L<Net::XMPP2::IM::Message> object with the to field set to
 this presence full JID.
 
+C<%args> are further arguments to the constructor of the message.
+
 =cut
 
+sub message_class { 'Net::XMPP2::IM::Message' }
+
 sub make_message {
-   my ($self) = @_;
-   Net::XMPP2::IM::Message->new (
+   my ($self, %args) = @_;
+   $self->message_class ()->new (
       connection => $self->{connection},
-      to         => $self->jid
+      to         => $self->jid,
+      %args
    );
 }
 
